==> ytian-3.0.7.tgz: package/utils/index.js <==
const path = require('path');
const fs = require('fs-extra');
const readPkg = require('read-pkg');
const writePkg = require('write-pkg');
const stringifyJS = require('javascript-stringify');

function createEmptyDirectories(directories, targetPath) {
  directories.forEach((directory) => {
    fs.ensureDirSync(`${targetPath}/${directory}`);
  });
}

exports.generateFiles = (projectName, projectPath, target, type) => {
  fs.copySync(path.join(__dirname, '../templates/common'), projectPath);
  fs.copySync(path.join(__dirname, `../templates/${type}`), projectPath);
  createEmptyDirectories(['test'], projectName);

  if (type !== 'component') {
    // template
    if (target === 'pc') {
      fs.copySync(path.join(__dirname, '../templates/pc'), `${projectName}/src`);
    }
    if (target === 'mobile') {
      fs.copySync(path.join(__dirname, '../templates/mobile'), `${projectName}/src`);
    }

    createEmptyDirectories(['assets', 'components', 'configs'], `${projectName}/src`);
    if (type !== 'spa') {
      createEmptyDirectories(['middlewares'], `${projectName}/src`);
    } else {
      createEmptyDirectories(['api'], `${projectName}/src`);
    }
    fs.outputFileSync(`${projectName}/.gitignore`, ['node_modules', '.DS_Store', '*.log', 'build'].join('\n'));
  } else {
    createEmptyDirectories(['lib', 'examples'], `${projectName}/src`);
    fs.outputFileSync(`${projectName}/src/index.js`, '');
    fs.outputFileSync(`${projectName}/.gitignore`, ['node_modules', '.DS_Store', '*.log', 'dist'].join('\n'));
  }

  const appConfig = {
    name: projectName,
    target,
    type,
  };
  const pkg = readPkg.sync(projectPath);

  /* eslint-disable-next-line no-underscore-dangle */
  delete pkg._id;
  delete pkg.readme;
  pkg.name = projectName;

  if (type !== 'cc-center') {
    delete pkg.dependencies.antd;
  }

  if (type === 'component') {
    pkg.dependencies = {};
  }

  // output config files.
  fs.outputFileSync(`${projectPath}/ytian.config.js`, `module.exports = ${stringifyJS(appConfig, null, 2)}`);
  writePkg.sync(projectPath, pkg);
};

==> ytian-3.0.9.tgz: package/utils/index.js <==
const path = require('path');
const fs = require('fs-extra');
const readPkg = require('read-pkg');
const writePkg = require('write-pkg');
const stringifyJS = require('javascript-stringify');

function createEmptyDirectories(directories, targetPath) {
  directories.forEach((directory) => {
    fs.ensureDirSync(`${targetPath}/${directory}`);
  });
}

exports.generateFiles = (projectName, projectPath, target, type) => {
  fs.copySync(path.join(__dirname, '../templates/common'), projectPath);
  fs.copySync(path.join(__dirname, `../templates/${type}`), projectPath);
  createEmptyDirectories(['test'], projectName);

  if (type !== 'component') {
    // template
    if (target === 'pc') {
      fs.copySync(path.join(__dirname, '../templates/pc'), `${projectName}/src`);
    }
    if (target === 'mobile') {
      fs.copySync(path.join(__dirname, '../templates/mobile'), `${projectName}/src`);
    }

    createEmptyDirectories(['assets', 'components', 'configs'], `${projectName}/src`);
    if (type !== 'spa') {
      createEmptyDirectories(['middlewares'], `${projectName}/src`);
    } else {
      createEmptyDirectories(['api'], `${projectName}/src`);
    }
    fs.outputFileSync(`${projectName}/.gitignore`, ['node_modules', '.DS_Store', '*.log', 'build'].join('\n'));
  } else {
    createEmptyDirectories(['examples'], `${projectName}`);
    fs.outputFileSync(`${projectName}/src/index.js`, '');
    fs.outputFileSync(`${projectName}/.gitignore`, ['node_modules', '.DS_Store', '*.log', 'dist'].join('\n'));
  }

  const appConfig = {
    name: projectName,
    target,
    type,
  };
  const pkg = readPkg.sync(projectPath);

  /* eslint-disable-next-line no-underscore-dangle */
  delete pkg._id;
  delete pkg.readme;
  pkg.name = projectName;

  if (type !== 'cc-center') {
    delete pkg.dependencies.antd;
  }

  if (type === 'component') {
    pkg.dependencies = {};
  }

  // output config files.
  fs.outputFileSync(`${projectPath}/ytian.config.js`, `module.exports = ${stringifyJS(appConfig, null, 2)}`);
  writePkg.sync(projectPath, pkg);
};
